package com.example.combustible;

import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.util.Vector;

import android.content.Context;
import android.database.Cursor;
import android.database.sqlite.SQLiteDatabase;
import android.database.sqlite.SQLiteOpenHelper;
import android.text.TextUtils;
import android.util.Log;

import com.example.combustible.Ciudad.Provincia;

public class RecuperarDatosSQL extends SQLiteOpenHelper {
	Context mContext;

	public RecuperarDatosSQL(Context context) {
		super(context, "poblacion", null, 1);
		mContext = context;
	}

	@Override
	public void onCreate(SQLiteDatabase db) {
		// CARGA BASE DE DATOS CON TODAS LAS CIUDADES Y PROVINCIAS
		// DESDE IMPORT EN ASSETS
		InputStream is = null;
		try {
			is = mContext.getAssets().open("bbdd/import.sql");
			if (is != null) {
				db.beginTransaction();
				BufferedReader reader = new BufferedReader(
						new InputStreamReader(is));
				String linea = reader.readLine();
				while (!TextUtils.isEmpty(linea)) {
					db.execSQL(linea);
					linea = reader.readLine();
				}
				db.setTransactionSuccessful();
			}
		} catch (Exception ex) {
			Log.e("Combustible", ex.getMessage());
		} finally {
			db.endTransaction();
			if (is != null) {
				try {
					is.close();
				} catch (IOException e) {
					Log.e("Combustible", e.getMessage());
				}
			}
		}

	}

	@Override
	public void onUpgrade(SQLiteDatabase db, int oldVersion, int newVersion) {
		// En caso de una nueva versin habra que actualizar las tablas
	}

	public Vector<Ciudad> leerProvincias() {

		// RECUPERA EL LISTADO DE PROVINCIAS
		Vector<Ciudad> recordsList = new Vector<Ciudad>();

		String sql = "";
		sql += "SELECT codProv, provincia FROM provincias";
		sql += " ORDER BY provincia";

		SQLiteDatabase db = this.getWritableDatabase();

		Cursor cursor = db.rawQuery(sql, null);

		if (cursor.moveToFirst()) {
			do {
				Ciudad ciudad = new Ciudad(cursor.getInt(0));
				ciudad.nombre = "";
				ciudad.provincia.nombre = cursor.getString(1);

				recordsList.add(ciudad);

			} while (cursor.moveToNext());
		}

		cursor.close();

		db.close();

		return recordsList;
	}

	public Vector<Ciudad> buscarCiudades(String searchTerm, Provincia provincia) {

		// RECUPERA LA CIUDAD DE LA PROVINCIA QUE CONTENGA EL STRING
		// PASADO COMO ARGUMENTO DEL TEXTO ESCRITO EN EL EDITTEXT
		Vector<Ciudad> recordsList = new Vector<Ciudad>();

		String sql = "";
		sql += "SELECT ciudades.codProv, ciudad, provincias.codProv, provincia FROM ciudades, provincias";
		sql += " WHERE ciudad LIKE '%" + searchTerm
				+ "%' AND ciudades.codProv=provincias.codProv";
		// SI SE HA PASADO ALGUNA PROVINCIA SE INCLUYE EN EL WHERE EN CASO
		// CONTRARIO NO
		if (provincia.codProv != 0) {
			sql += " AND ciudades.codProv=" + provincia.codProv;
		}
		// EL NMERO MXIMO DE CIUDADES DEVUELTAS ES EL DE LA PROVINCIA CON MAS
		// CIUDADES
		sql += " ORDER BY ciudad LIMIT 0,203";

		SQLiteDatabase db = this.getWritableDatabase();
		Cursor cursor = db.rawQuery(sql, null);

		if (cursor.moveToFirst()) {
			do {
				Ciudad ciudad = new Ciudad(cursor.getInt(0),
						cursor.getString(1));
				ciudad.provincia.nombre = cursor.getString(3);

				recordsList.add(ciudad);

			} while (cursor.moveToNext());
		}

		cursor.close();

		db.close();

		return recordsList;
	}
}
